蝙蝠侠：黑暗骑士 (豆瓣)
Description: 蝙蝠侠：黑暗骑士电影简介和剧情介绍,蝙蝠侠：黑暗骑士影评、图片、预告片、影讯、论坛、在线购票
Keywords: 蝙蝠侠：黑暗骑士,The Dark Knight,蝙蝠侠：黑暗骑士影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.29豆瓣电影Top250

# 蝙蝠侠：黑暗骑士 The Dark Knight (2008)

导演: 克里斯托弗·诺兰
编剧: 乔纳森·诺兰 / 克里斯托弗·诺兰 / 大卫·S·高耶
主演: 克里斯蒂安·贝尔 / 希斯·莱杰 / 艾伦·艾克哈特 / 迈克尔·凯恩 / 玛吉·吉伦哈尔 / 加里·奥德曼 / 摩根·弗里曼 / 莫尼克·加布里埃拉·库尔内 / 罗恩·迪恩 / 基里安·墨菲 / 黄经汉 / 内斯特·卡博内尔 / 埃里克·罗伯茨 / 里特奇·科斯特 / 安东尼·迈克尔·豪尔 / 基斯·斯扎拉巴基克 / 柯林·麦克法兰 / 约书亚·哈尔托 / 美琳达·麦格劳 / 内森·甘宝 / 迈克尔·维约 / 迈克尔·斯托扬诺夫 / 威廉·斯米利 / 丹尼·高德林 / 迈克尔·加·怀特 / 马修·奥尼尔 / 威廉·菲克纳 / 欧鲁米基·欧拉乌米 / 格雷格·比姆 / 爱利克·赫尔曼 / 毕崔斯·罗森 / 文森佐·尼克力 / 陈冠希
类型: 剧情 / 动作 / 科幻 / 惊悚 / 犯罪
官方网站: thedarkknight.warnerbros.com
制片国家/地区: 美国 / 英国
语言: 英语 / 汉语普通话
上映日期: 2008-07-14(纽约首映) / 2008-07-18(美国)
片长: 152分钟
又名: 蝙蝠侠前传2：黑暗骑士 / 黑暗骑士(台) / 蝙蝠侠-黑夜之神(港) / 蝙蝠侠6：暗夜骑士 / Batman: The Dark Knight / TDK
IMDb: tt0468569
豆瓣评分
引用
9.2
1005945人评价
5星
67.8%
4星
25.9%
3星
5.6%
2星
0.4%
1星
0.2%
好于 99% 科幻片
好于 99% 犯罪片
想看 看过
评价:
推荐

## 蝙蝠侠：黑暗骑士的剧情简介 · · · · · ·

从亲眼目睹父母被人杀死的阴影中走出来的“蝙蝠侠”，经历了成长之后，已经不再是那个桀骜不的孤单英雄了。在警官吉姆·戈登和检查官哈维·登特的通力帮助下，“蝙蝠侠”无后顾之忧地继续满世界的奔波，与日益增长起来的犯罪威胁做着永无休止的争斗，而他所在的高谭市，也是进展最为明显的地方，犯罪率以一种惊人的速度持续下降着，毕竟对方是能够上天入地的“蝙蝠侠”，不借两个胆子谁还敢造次呢？不过像高谭这种科技与污秽并存的城市，平静是不可能维持太久的，果不其然，新一轮的混乱很快就席卷了整个城市，人们再一被被恐慌所笼罩着，而声称愿意为这一切负责的，自然就是所有混乱的源头以及支配者--“小丑”了。
先不管“小丑”掀起一个又一个犯罪的狂潮的最终目的为何，他的企图都是邪恶的，所作所为更是早就危害到了高谭市民的正常生活……其中自然包括了“蝙蝠侠”身边几个非常重要的人，而他需要做的，就是... (展开全部) 从亲眼目睹父母被人杀死的阴影中走出来的“蝙蝠侠”，经历了成长之后，已经不再是那个桀骜不的孤单英雄了。在警官吉姆·戈登和检查官哈维·登特的通力帮助下，“蝙蝠侠”无后顾之忧地继续满世界的奔波，与日益增长起来的犯罪威胁做着永无休止的争斗，而他所在的高谭市，也是进展最为明显的地方，犯罪率以一种惊人的速度持续下降着，毕竟对方是能够上天入地的“蝙蝠侠”，不借两个胆子谁还敢造次呢？不过像高谭这种科技与污秽并存的城市，平静是不可能维持太久的，果不其然，新一轮的混乱很快就席卷了整个城市，人们再一被被恐慌所笼罩着，而声称愿意为这一切负责的，自然就是所有混乱的源头以及支配者--“小丑”了。
先不管“小丑”掀起一个又一个犯罪的狂潮的最终目的为何，他的企图都是邪恶的，所作所为更是早就危害到了高谭市民的正常生活……其中自然包括了“蝙蝠侠”身边几个非常重要的人，而他需要做的，就是将这股新的危机全部亲自用手捏得粉碎。然而在面对着这个有史以来最具针对性、最恶毒的对手时，“蝙蝠侠”却不得不从他的地下军械库里搬出每一件能够用得上的高科技武器，还得时刻纠结着为他曾经信仰的一切寻找答案。 ©豆瓣

## 蝙蝠侠：黑暗骑士的演职员 · · · · · · ( 全部 53 )

- 克里斯托弗·诺兰 导演
- 克里斯蒂安·贝尔 饰 布鲁斯·韦恩 / 蝙蝠侠 Bruce Wayne / Batman
- 希斯·莱杰 饰 小丑 Joker
- 艾伦·艾克哈特 饰 哈维·丹特 Harvey Dent
- 迈克尔·凯恩 饰 阿尔弗雷德 Alfred
- 玛吉·吉伦哈尔 饰 瑞秋 Rachel

## 蝙蝠侠：黑暗骑士的视频和图片 · · · · · · ( 预告片4 | 视频评论3 · 添加 | 图片2282 · 添加 )

## 蝙蝠侠：黑暗骑士的获奖情况 · · · · · · ( 全部 )

- 第81届奥斯卡金像奖
- 最佳男配角
- 希斯·莱杰

- 第66届金球奖
- 电影类 最佳男配角
- 希斯·莱杰

- 第32届日本电影学院奖
- 最佳外语片

## 喜欢这部电影的人也喜欢 · · · · · ·

  蝙蝠侠：黑暗骑士崛起

  黑客帝国

  猫鼠游戏

  钢铁侠

  终结者2：审判日

  复仇者联盟

  阿凡达

  盗梦空间

  美国队长2

  变形金刚

我要写短评

## 蝙蝠侠：黑暗骑士的短评 · · · · · · ( 全部 174555 条 )

热门 / 最新 / 好友

### 17874 有用 bayer04 看过 2008-08-29 22:07:30

诺兰接手后蝙蝠侠和其它漫画英雄片完全不是一个等级了

### 10021 有用 Lan~die 看过 2008-09-05 00:00:06

蝙蝠侠、双面人和小丑这三个形象把人在善恶两面的矛盾及选择映射得淋漓尽致，于是成就了史上最佳漫画和英雄电影。时光网：“诺兰让关于艺术片和商业片的讨论变得毫无价值。《黑暗骑士》不但拍出了古典悲剧的感觉，还探讨了恐怖主义、越界权力等美国当代的热点话题。最关键的是，电影好看得无懈可击。”

### 6841 有用 fishlee 看过 2009-07-28 10:21:42

大片中很有内涵的一部，不管是人们心中暗自涌动的对小丑疯狂灭世主义的不安的共鸣，还是对蝙蝠侠孤独暗夜行走的英雄惜英雄般同情，其实都是人们对这个世界失望的一种情绪释放。其实小丑说的很对，他和蝙蝠侠很像，都是异类，只不过蝙蝠侠把痛苦留给自己，顽固地去坚守一丝信仰，而小丑把痛苦还给世界。

### 4515 有用 37°2 看过 2008-11-21 12:41:29

赞誉众口一致夸上了天，百闻不如一见，这种连环画超级英雄故事居然能扯到第六集真是要把编剧逼跳楼了，最后呈现的暗夜骑士全然超越了原著，悲怆到迷人的境界，着实是个奇迹。剧本确实很卓越，导演确实很出色，还有演技真是不得不叹服一下太tmd震撼

### 6200 有用 evonne||芝士命 看过 2009-05-16 11:12:11

好到一秒钟都不曾浪费

> 更多短评 174555条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 蝙蝠侠：黑暗骑士的影评 · · · · · · ( 全部 2427 条 )

热门 / 最新 / 好友
武志红 2009-01-23 17:46:44

## 蝙蝠侠与小丑：同一硬币的两面？

这篇影评可能有剧透

【22日，美国第81届奥斯卡奖的提名名单公布，令人们大跌眼镜的是，2008年全球票房冠军、好莱坞历史上第二卖座的《蝙蝠侠·暗夜骑士》只拿到了数项无关痛痒的提名。 不过，评委们可以轻视这部影片，但却不能轻视影片中的反角小丑，饰演小丑的演员希斯·莱杰众望所归获得了最佳配... (展开)
15213 686 892回应 收起
Evarnold 2008-10-11 20:21:21

## 当阁下望着深渊时，深渊也在望着阁下

图文载自我SPACE http://evarnold7.spaces.live.com/blog/cns!3C4928A5D97A0C8E!833.entry 老师从小教育我们，要开展批评，先要先开展自我批评。于是在剖析《黑暗骑士THE DARK KNIGHT》之前，我先剖析我为什么看枪版。 ——————我是自我剖析线—————— 对于很多... (展开)
3252 113 311回应 收起
恒殊 2008-07-29 00:38:03

## Mourning for Heath Ledger

Heath Ledger去世的那一天，清楚记得，在早上的Marketing课上，Kiera进门的第一句话，你听说了么，昨天Heath Ledger死了。他是那天伦敦各家日报的头条。死因是服药过量。昨天Pete的室友Rob和我说，我和他吃的是一种药。那你快别吃了，我说。不吃的话我睡不着。年轻的Rob摊了摊... (展开)
1153 213 181回应 收起
Bono 2008-11-24 15:32:45

## 糖果盒骑士

看这部电影的时候，刚好前阵闹轰轰的哈尔滨糖果盒事件出了结果，先是尸检的结果出来了，人确实是被打死的，然后就是几名警察被批准逮捕，往后过去的同行见着他们，不必再称呼“我们的人”或“我们的警察”了，直接喊内谁或者老犯儿就行了，简单粗暴。实话实说，这个结果叫... (展开)
926 105 103回应 收起
肥蟹 2009-02-02 21:42:08

## 从心理学角度看小丑、蝙蝠侠、丹特

转自广州日报，心理学专栏 武志红 　　22日，美国第81届奥斯卡奖的提名名单公布，令人们大跌眼镜的是，2008年全球票房冠军、好莱坞历史上第二卖座的《蝙蝠侠·暗夜骑士》只拿到了数项无关痛痒的提名。 　　不过，评委们可以轻视这部影片，但却不能轻视影片中的反角小丑，饰... (展开)
780 43 81回应 收起
N米 2012-11-19 13:50:47

## 《黑暗骑士》带给我的五年

上一次写影评都是好遥远的事情了，在高中的时候，因为寂寞到没有人跟我高谈电影，我便自发的自己给自己写影评来跟自己对话。导致艺考的时候影评是我最得意的一项。 大学进入了电影圣殿，每天都在说着电影，太过美好了。 毕业后，有次去找嘉恒，再一次聊着最近看的佳作。嘉恒... (展开)
625 54 81回应 收起
忏悔的仪表盘 2012-03-24 17:12:15

## 全面解析 小丑经典台词

这篇影评可能有剧透

转载。 ————全力解读小丑台词以及潜台词 经典角色总是被人们常常提及，这次也不例外，唯一不同的是我也加进来了，而且是十分认真的，花了不少功夫伤了不少脑筋，不过还是值得的，做自己喜欢做的事的时候总是会全力以赴，不遗余力。 我们可以发现在《黑暗骑士》这... (展开)
627 77 49回应 收起
吴嘎嘎 2008-08-08 10:48:30

## 美国人民的蝙蝠侠和中国淫民的冠希哥

乔治卢卡斯，斯皮尔伯格之后，谁是美国主流商业电影的接棒人呢？毫无疑问，christopher nolan正以势如破竹之势日夜兼程的霸占美国市场，现在看来，结果不错，数以千万的美国观众纷纷掏出腰包进入影院观看这部《the dark knight》。我们从来不用质疑大多数美国影迷们的浅薄口... (展开)
574 312 177回应 收起
何倩彤 2008-08-22 01:54:18

## 綠鬢詩人，並五絲六縷

給Heath Ledger the Joker ( 讀著亨利米勒(Henry Miller)的《謀殺者的時代》(The Time of The Assassins)，那一、兩篇討論蘭波(Arthur Rimbaud)的文章，當中講及到詩人在末日亂世中的身份、責任與毀亡，我竟然覺得，寫於一九六二年的那些，和"Dark Knight"中的joker有了對... (展开)
172 24 63回应 收起
wwei 2008-11-30 15:37:42

## All the little things made this movie iconic

之所以写这个是因为很多人只看到最表层的东西。之前曾想给《The Prestige》写一篇类似的评论，但实在太懒，因而一直没有写成。看这部电影时的感觉跟《The Prestige》有点类似，也是为一些细节内容着迷不已。 A.比喻、对比、暗示 1、25052大街：Rachel被炸死、以及Harvey De... (展开)
221 10 21回应 收起

> 更多影评 2427篇

添加新讨论

## 讨论区 · · · · · ·

再论本片为什么令人恶心 | 来自Bekanoi | 243 回应 | 2022-11-23 22:28:12
Cillian Murphy? | 来自alexalium | 1 回应 | 2022-11-19 16:24:44
不是我针对那女的,有没有人觉得她长得很像大妈?! | 来自所向披靡潘小姆 | 30 回应 | 2022-11-16 17:29:20
请问三部曲在b站上的版本有删减吗 | 来自lisihan | 4 回应 | 2022-11-15 15:16:03
有人问为什么还有人住在哥谭市 | 来自晨线 |  | 2022-11-15 08:08:24

> 去这部影片的讨论区（全部882条）

## 关于《蝙蝠侠：黑暗骑士》的问题 · · · · · · ( 全部68个 )

- joker和蝙蝠侠究竟谁算得上赢了？ 19人回答
- 演员表里有冠希陈老师 为啥我没有看到？ 8人回答

> 全部68个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 他们是高智商玩家 (中间元素)
- 高智商互斗电影 (中间元素)
- {北美电影票房总排行} (荔枝超人)

## 谁在看这部电影 · · · · · ·

- Victor
  刚刚 看过
- momo
  1分钟前 看过
- Happy欢欢欢豆乐
  3分钟前 看过

1670315人看过 / 252945人想看

订阅蝙蝠侠：黑暗骑士的评论:
feed: rss 2.0